@@ -140,7 +140,6 @@ ews_store_initable_init (GInitable *initable,
 
 	store = CAMEL_STORE (initable);
 	service = CAMEL_SERVICE (initable);
-	session = camel_service_get_session (service);
 
 	store->flags |= CAMEL_STORE_USE_CACHE_DIR;
 	ews_migrate_to_user_cache_dir (service);
@@ -149,8 +148,12 @@ ews_store_initable_init (GInitable *initable,
 	if (!parent_initable_interface->init (initable, cancellable, error))
 		return FALSE;
 
+	session = camel_service_ref_session (service);
+
 	ret = ews_store_construct (service, session, NULL, error);
 
+	g_object_unref (session);
+
 	/* Add transport here ? */
 
 	return ret;
@@ -467,9 +470,10 @@ ews_update_folder_hierarchy (CamelEwsStore *ews_store,
                              gboolean includes_last_folder,
                              GSList *folders_created,
                              GSList *folders_deleted,
-                             GSList *folders_updated)
+                             GSList *folders_updated,
+			     GSList **created_folder_ids)
 {
-	ews_utils_sync_folders (ews_store, folders_created, folders_deleted, folders_updated);
+	ews_utils_sync_folders (ews_store, folders_created, folders_deleted, folders_updated, created_folder_ids);
 	camel_ews_store_ensure_virtual_folders (ews_store);
 
 	camel_ews_store_summary_store_string_val (ews_store->summary, "sync_state", sync_state);
@@ -495,7 +499,6 @@ ews_connect_sync (CamelService *service,
 	gboolean success;
 
 	ews_store = CAMEL_EWS_STORE (service);
-	session = camel_service_get_session (service);
 
 	if (camel_service_get_connection_status (service) == CAMEL_SERVICE_DISCONNECTED)
 		return FALSE;
@@ -506,11 +509,15 @@ ews_connect_sync (CamelService *service,
 		return TRUE;
 	}
 
+	session = camel_service_ref_session (service);
+
 	/* Try running an operation that requires authentication
 	 * to make sure we have a valid password available. */
 	success = camel_session_authenticate_sync (
 		session, service, NULL, cancellable, error);
 
+	g_object_unref (session);
+
 	if (success)
 		camel_offline_store_set_online_sync (
 			CAMEL_OFFLINE_STORE (ews_store),
@@ -590,10 +597,13 @@ ews_store_set_flags (CamelEwsStore *ews_store,
 	temp = folders;
 	while (temp != NULL) {
 		folder = (EEwsFolder *) temp->data;
-		fid = e_ews_folder_get_id (folder);
 
-		if (camel_ews_store_summary_has_folder (ews_store->summary, fid->id))
-			camel_ews_store_summary_set_folder_flags (ews_store->summary, fid->id, system_folder[n].info_flags);
+		if (folder && !e_ews_folder_is_error (folder)) {
+			fid = e_ews_folder_get_id (folder);
+
+			if (camel_ews_store_summary_has_folder (ews_store->summary, fid->id))
+				camel_ews_store_summary_set_folder_flags (ews_store->summary, fid->id, system_folder[n].info_flags);
+		}
 
 		temp = temp->next;
 		n++;
@@ -803,15 +813,18 @@ camel_ews_store_update_foreign_subfolders (CamelEwsStore *ews_store,
 	g_return_if_fail (CAMEL_IS_EWS_STORE (ews_store));
 	g_return_if_fail (fid != NULL);
 
-	session = camel_service_get_session (CAMEL_SERVICE (ews_store));
-	g_return_if_fail (CAMEL_IS_SESSION (session));
+	session = camel_service_ref_session (CAMEL_SERVICE (ews_store));
+	g_return_if_fail (session != NULL);
 
 	euf = g_new0 (struct EwsUpdateForeignSubfoldersData, 1);
 	euf->ews_store = g_object_ref (ews_store);
 	euf->folder_id = g_strdup (fid);
 
-	camel_session_submit_job (session, ews_store_update_foreign_subfolders,
+	camel_session_submit_job (
+		session, ews_store_update_foreign_subfolders,
 		euf, ews_update_foreign_subfolders_data_free);
+
+	g_object_unref (session);
 }
 
 static void
@@ -902,11 +915,13 @@ ews_store_maybe_update_sent_and_drafts (CamelEwsStore *ews_store,
 
 					if (ii < G_N_ELEMENTS (system_folder)) {
 						EEwsFolder *drafts = g_slist_nth (ews_folders, ii)->data;
-						const EwsFolderId *fid = drafts ? e_ews_folder_get_id (drafts) : NULL;
+						if (drafts && !e_ews_folder_is_error (drafts)) {
+							const EwsFolderId *fid = e_ews_folder_get_id (drafts);
 
-						if (fid && fid->id) {
-							changed = TRUE;
-							ews_store_update_source_extension_folder (ews_store, fid->id, coms_extension, "drafts-folder");
+							if (fid && fid->id) {
+								changed = TRUE;
+								ews_store_update_source_extension_folder (ews_store, fid->id, coms_extension, "drafts-folder");
+							}
 						}
 					}
 				}
@@ -939,6 +954,7 @@ ews_authenticate_sync (CamelService *service,
 	GSList *folders_updated = NULL;
 	GSList *folders_deleted = NULL;
 	GSList *folder_ids = NULL, *folders = NULL;
+	GSList *created_folder_ids = NULL;
 	gboolean includes_last_folder = FALSE;
 	gboolean initial_setup = FALSE;
 	const gchar *password;
@@ -1013,7 +1029,7 @@ ews_authenticate_sync (CamelService *service,
 		/* This consumes all allocated result data. */
 		ews_update_folder_hierarchy (
 			ews_store, new_sync_state, includes_last_folder,
-			folders_created, folders_deleted, folders_updated);
+			folders_created, folders_deleted, folders_updated, &created_folder_ids);
 
 		/* Also update folder structures of foreign folders,
 		   those which are subscribed with subfolders */
@@ -1063,7 +1079,7 @@ ews_authenticate_sync (CamelService *service,
 			NULL, folder_ids, &folders,
 			cancellable, &folder_err);
 
-		if (g_slist_length (folders) && (g_slist_length (folders) != G_N_ELEMENTS (system_folder)))
+		if (folders && (g_slist_length (folders) != G_N_ELEMENTS (system_folder)))
 			d (printf ("Error : not all folders are returned by getfolder operation"));
 		else if (folder_err == NULL && folders != NULL)
 			ews_store_set_flags (ews_store, folders);
@@ -1086,6 +1102,19 @@ ews_authenticate_sync (CamelService *service,
 		g_clear_error (&folder_err);
 	}
 
+	/* postpone notification of new folders to time when also folder flags are known,
+	   thus the view in evolution sows Inbox with an Inbox icon. */
+	for (folder_ids = created_folder_ids; folder_ids; folder_ids = folder_ids->next) {
+		CamelFolderInfo *fi;
+
+		fi = camel_ews_utils_build_folder_info (ews_store, folder_ids->data);
+		camel_store_folder_created (CAMEL_STORE (ews_store), fi);
+		camel_subscribable_folder_subscribed (CAMEL_SUBSCRIBABLE (ews_store), fi);
+		camel_folder_info_free (fi);
+	}
+
+	g_slist_free_full (created_folder_ids, g_free);
+
 	if (local_error == NULL) {
 		result = CAMEL_AUTHENTICATION_ACCEPTED;
 	} else if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_AUTHENTICATION_FAILED)) {
@@ -1305,7 +1334,7 @@ folder_info_from_store_summary (CamelEwsStore *store,
 
 					settings = camel_service_ref_settings (CAMEL_SERVICE (store));
 					ews_settings = CAMEL_EWS_SETTINGS (settings);
-					session = camel_service_get_session (CAMEL_SERVICE (store));
+					session = camel_service_ref_session (CAMEL_SERVICE (store));
 					if (E_IS_MAIL_SESSION (session))
 						registry = e_mail_session_get_registry (E_MAIL_SESSION (session));
 
@@ -1314,6 +1343,7 @@ folder_info_from_store_summary (CamelEwsStore *store,
 					esources = e_ews_folder_utils_get_esources (registry, hosturl, username, cancellable, NULL);
 
 					g_object_unref (settings);
+					g_object_unref (session);
 				}
 
 				if (e_ews_folder_utils_is_subscribed_as_esource (esources, hosturl, username, fid->id))
@@ -1401,7 +1431,7 @@ ews_folder_hierarchy_ready_cb (GObject *obj,
 	g_mutex_lock (&priv->get_finfo_lock);
 	ews_update_folder_hierarchy (
 		ews_store, sync_state, includes_last_folder,
-		folders_created, folders_deleted, folders_updated);
+		folders_created, folders_deleted, folders_updated, NULL);
 
 	ews_store->priv->last_refresh_time = time (NULL);
 	g_mutex_unlock (&priv->get_finfo_lock);
@@ -1612,7 +1642,7 @@ ews_get_folder_info_sync (CamelStore *store,
 	}
 	ews_update_folder_hierarchy (
 		ews_store, new_sync_state, includes_last_folder,
-		folders_created, folders_deleted, folders_updated);
+		folders_created, folders_deleted, folders_updated, NULL);
 	g_mutex_unlock (&priv->get_finfo_lock);
 
 offline:
@@ -2343,7 +2373,7 @@ ews_store_subscribe_folder_sync (CamelSubscribable *subscribable,
 
 		settings = camel_service_ref_settings (CAMEL_SERVICE (ews_store));
 		ews_settings = CAMEL_EWS_SETTINGS (settings);
-		session = camel_service_get_session (CAMEL_SERVICE (ews_store));
+		session = camel_service_ref_session (CAMEL_SERVICE (ews_store));
 		if (E_IS_MAIL_SESSION (session))
 			registry = e_mail_session_get_registry (E_MAIL_SESSION (session));
 
@@ -2356,6 +2386,7 @@ ews_store_subscribe_folder_sync (CamelSubscribable *subscribable,
 			cancellable,
 			error);
 
+		g_object_unref (session);
 		g_object_unref (settings);
 	}
 
@@ -2477,7 +2508,7 @@ ews_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
 
 			settings = camel_service_ref_settings (CAMEL_SERVICE (ews_store));
 			ews_settings = CAMEL_EWS_SETTINGS (settings);
-			session = camel_service_get_session (CAMEL_SERVICE (ews_store));
+			session = camel_service_ref_session (CAMEL_SERVICE (ews_store));
 			if (E_IS_MAIL_SESSION (session))
 				registry = e_mail_session_get_registry (E_MAIL_SESSION (session));
 
@@ -2488,6 +2519,7 @@ ews_store_unsubscribe_folder_sync (CamelSubscribable *subscribable,
 				cancellable,
 				error);
 
+			g_object_unref (session);
 			g_object_unref (settings);
 		}
 
